timeintervaltools.TimeInterval
==============================

.. abjad-lineage:: abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval

.. autoclass:: abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.bounds
   :noindex:

.. autoattribute:: abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.center
   :noindex:

.. autoattribute:: abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.duration
   :noindex:

.. autoattribute:: abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.signature
   :noindex:

.. autoattribute:: abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.start
   :noindex:

.. autoattribute:: abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.stop
   :noindex:

.. autoattribute:: abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.storage_format
   :noindex:

Methods
-------

.. automethod:: abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.clear
   :noindex:

.. automethod:: abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.get
   :noindex:

.. automethod:: abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.get_overlap_with_interval
   :noindex:

.. automethod:: abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.is_contained_by_interval
   :noindex:

.. automethod:: abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.is_container_of_interval
   :noindex:

.. automethod:: abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.is_overlapped_by_interval
   :noindex:

.. automethod:: abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.is_tangent_to_interval
   :noindex:

.. automethod:: abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.items
   :noindex:

.. automethod:: abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.iteritems
   :noindex:

.. automethod:: abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.iterkeys
   :noindex:

.. automethod:: abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.itervalues
   :noindex:

.. automethod:: abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.keys
   :noindex:

.. automethod:: abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.pop
   :noindex:

.. automethod:: abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.popitem
   :noindex:

.. automethod:: abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.quantize_to_rational
   :noindex:

.. automethod:: abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.scale_by_rational
   :noindex:

.. automethod:: abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.scale_to_rational
   :noindex:

.. automethod:: abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.setdefault
   :noindex:

.. automethod:: abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.shift_by_rational
   :noindex:

.. automethod:: abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.shift_to_rational
   :noindex:

.. automethod:: abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.split_at_rationals
   :noindex:

.. automethod:: abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.update
   :noindex:

.. automethod:: abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.values
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.__contains__
   :noindex:

.. automethod:: abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.__delitem__
   :noindex:

.. automethod:: abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.__eq__
   :noindex:

.. automethod:: abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.__ge__
   :noindex:

.. automethod:: abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.__getitem__
   :noindex:

.. automethod:: abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.__gt__
   :noindex:

.. automethod:: abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.__hash__
   :noindex:

.. automethod:: abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.__iter__
   :noindex:

.. automethod:: abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.__le__
   :noindex:

.. automethod:: abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.__len__
   :noindex:

.. automethod:: abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.__lt__
   :noindex:

.. automethod:: abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.__ne__
   :noindex:

.. automethod:: abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.__nonzero__
   :noindex:

.. automethod:: abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.__repr__
   :noindex:

.. automethod:: abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval.__setitem__
   :noindex:
